`Release history`_
##################

2.2.0 - 06-10-2020
==================

* Add Django 3.0 and 3.1 support
* Add django-ipware 3 support

2.1.1 - 10-01-2020
==================
* Fix Travis CI deployment to PyPi


2.1.0 - 10-01-2020
==================
* Add TRUST_PRIVATE_IP settings (default: `False`)


2.0.0 - 10-01-2019
==================
* Drop Django 1.10 support
* Drop Python 3.4 support
* Add Django 2.1 and 2.2 support
* Switch to Travis CI

.. _Release history: https://pypi.org/project/django-admin-ip-restrictor/#history